@@ -13,7 +13,12 @@ FIPS.name<-function(data,ID.case,long.case,lat.case,map=NULL,state.map,level.map
     if(is.null(map)&level.map=="tract") NYSmap=tigris::tracts(state=state.map) else NYSmap=map
   }
   raster::crs(data1)=raster::crs(NYSmap)
-  data1=spatialEco::point.in.poly(data1,NYSmap)
+  data1=sf::st_as_sf(data1)
+  NYSmap=sf::st_as_sf(NYSmap)
+  if (dim(data1)[2] == 1) data1$pt.ids <- 1:nrow(data1)
+  if (dim(NYSmap)[2] == 1) NYSmap$poly.ids <- 1:nrow(NYSmap)
+  data1=sf::st_join(data1, NYSmap,largest = TRUE)
+  data1=methods::as(data1, "Spatial")
   data1=as.data.frame(data1)
   data1=cbind(data1[,1:(a-2)],data1[,areaID])
   names(data1)[ncol(data1)]="areaID"
